Given a player name or rank, and a competition category, get_player_rankings_history() returns a tidy version of the PSA rankings history table for that player(s).
Given the player name, rank(s), and competition category, get_player_profile_urls() returns profile slugs of ranked players in PSA World Tour competitions.
get_player_profile_urls(
player = NULL,
rank = NULL,
category = c("mens", "womens")
)get_player_profile_urls(
player = NULL,
rank = NULL,
category = c("mens", "womens")
)
character string of player name.
single integer or vector of integers indicating the rank of the PSA player(s) to return.
character string indicating the competition category. Must be one of "both", "mens", or "womens".
Tibble containing the year, month, exact date, rank, player name and player's current rank.
Data frame containing player ranks, names, and profile slugs.