# NOT RUN {
## Get the rankings history for the top two men's singles players
# }
# NOT RUN {
top_two <- get_player_rankings_history(rank = 1:2, category = "mens")
# }
# NOT RUN {
## Get the rankings history for the top three women's singles players
# }
# NOT RUN {
top_three <- get_player_rankings_history(rank = 1:3, category = "womens")
# }
# NOT RUN {
# }
Run the code above in your browser using DataLab